@@ -54,8 +54,11 @@ R_CallMethodDef library_WRAPPER_AUTO_H5D[] = {
 {"R_H5Dformat_convert", (DL_FUNC) &R_H5Dformat_convert, 1},
 {"R_H5Dget_access_plist", (DL_FUNC) &R_H5Dget_access_plist, 1},
 {"R_H5Dget_chunk_index_type", (DL_FUNC) &R_H5Dget_chunk_index_type, 2},
+{"R_H5Dget_chunk_info", (DL_FUNC) &R_H5Dget_chunk_info, 7},
+{"R_H5Dget_chunk_info_by_coord", (DL_FUNC) &R_H5Dget_chunk_info_by_coord, 5},
 {"R_H5Dget_chunk_storage_size", (DL_FUNC) &R_H5Dget_chunk_storage_size, 3},
 {"R_H5Dget_create_plist", (DL_FUNC) &R_H5Dget_create_plist, 1},
+{"R_H5Dget_num_chunks", (DL_FUNC) &R_H5Dget_num_chunks, 3},
 {"R_H5Dget_offset", (DL_FUNC) &R_H5Dget_offset, 1},
 {"R_H5Dget_space", (DL_FUNC) &R_H5Dget_space, 1},
 {"R_H5Dget_space_status", (DL_FUNC) &R_H5Dget_space_status, 2},
@@ -111,12 +114,15 @@ R_CallMethodDef library_WRAPPER_AUTO_H5F[] = {
 {"R_H5Fclear_elink_file_cache", (DL_FUNC) &R_H5Fclear_elink_file_cache, 1},
 {"R_H5Fclose", (DL_FUNC) &R_H5Fclose, 1},
 {"R_H5Fcreate", (DL_FUNC) &R_H5Fcreate, 4},
+{"R_H5Fdelete", (DL_FUNC) &R_H5Fdelete, 2},
 {"R_H5Fflush", (DL_FUNC) &R_H5Fflush, 2},
 {"R_H5Fformat_convert", (DL_FUNC) &R_H5Fformat_convert, 1},
 {"R_H5Fget_access_plist", (DL_FUNC) &R_H5Fget_access_plist, 1},
 {"R_H5Fget_create_plist", (DL_FUNC) &R_H5Fget_create_plist, 1},
+{"R_H5Fget_dset_no_attrs_hint", (DL_FUNC) &R_H5Fget_dset_no_attrs_hint, 2},
 {"R_H5Fget_eoa", (DL_FUNC) &R_H5Fget_eoa, 2},
 {"R_H5Fget_file_image", (DL_FUNC) &R_H5Fget_file_image, 4},
+{"R_H5Fget_fileno", (DL_FUNC) &R_H5Fget_fileno, 2},
 {"R_H5Fget_filesize", (DL_FUNC) &R_H5Fget_filesize, 2},
 {"R_H5Fget_free_sections", (DL_FUNC) &R_H5Fget_free_sections, 4},
 {"R_H5Fget_freespace", (DL_FUNC) &R_H5Fget_freespace, 1},
@@ -134,12 +140,14 @@ R_CallMethodDef library_WRAPPER_AUTO_H5F[] = {
 {"R_H5Fget_obj_ids", (DL_FUNC) &R_H5Fget_obj_ids, 4},
 {"R_H5Fget_page_buffering_stats", (DL_FUNC) &R_H5Fget_page_buffering_stats, 6},
 {"R_H5Fincrement_filesize", (DL_FUNC) &R_H5Fincrement_filesize, 2},
+{"R_H5Fis_accessible", (DL_FUNC) &R_H5Fis_accessible, 2},
 {"R_H5Fis_hdf5", (DL_FUNC) &R_H5Fis_hdf5, 1},
 {"R_H5Fmount", (DL_FUNC) &R_H5Fmount, 4},
 {"R_H5Fopen", (DL_FUNC) &R_H5Fopen, 3},
 {"R_H5Freopen", (DL_FUNC) &R_H5Freopen, 1},
 {"R_H5Freset_mdc_hit_rate_stats", (DL_FUNC) &R_H5Freset_mdc_hit_rate_stats, 1},
 {"R_H5Freset_page_buffering_stats", (DL_FUNC) &R_H5Freset_page_buffering_stats, 1},
+{"R_H5Fset_dset_no_attrs_hint", (DL_FUNC) &R_H5Fset_dset_no_attrs_hint, 2},
 {"R_H5Fset_latest_format", (DL_FUNC) &R_H5Fset_latest_format, 2},
 {"R_H5Fset_libver_bounds", (DL_FUNC) &R_H5Fset_libver_bounds, 3},
 {"R_H5Fset_mdc_config", (DL_FUNC) &R_H5Fset_mdc_config, 2},
@@ -318,20 +326,27 @@ R_CallMethodDef library_WRAPPER_AUTO_H5O[] = {
 {"R_H5Oflush", (DL_FUNC) &R_H5Oflush, 1},
 {"R_H5Oget_comment", (DL_FUNC) &R_H5Oget_comment, 3},
 {"R_H5Oget_comment_by_name", (DL_FUNC) &R_H5Oget_comment_by_name, 5},
-{"R_H5Oget_info_by_idx1", (DL_FUNC) &R_H5Oget_info_by_idx1, 7},
+{"R_H5Oget_info", (DL_FUNC) &R_H5Oget_info, 2},
+{"R_H5Oget_info_by_idx", (DL_FUNC) &R_H5Oget_info_by_idx, 7},
 {"R_H5Oget_info_by_idx2", (DL_FUNC) &R_H5Oget_info_by_idx2, 8},
-{"R_H5Oget_info_by_name1", (DL_FUNC) &R_H5Oget_info_by_name1, 4},
+{"R_H5Oget_info_by_name", (DL_FUNC) &R_H5Oget_info_by_name, 4},
 {"R_H5Oget_info_by_name2", (DL_FUNC) &R_H5Oget_info_by_name2, 5},
-{"R_H5Oget_info1", (DL_FUNC) &R_H5Oget_info1, 2},
 {"R_H5Oget_info2", (DL_FUNC) &R_H5Oget_info2, 3},
+{"R_H5Oget_native_info", (DL_FUNC) &R_H5Oget_native_info, 3},
+{"R_H5Oget_native_info_by_idx", (DL_FUNC) &R_H5Oget_native_info_by_idx, 8},
+{"R_H5Oget_native_info_by_name", (DL_FUNC) &R_H5Oget_native_info_by_name, 5},
 {"R_H5Oincr_refcount", (DL_FUNC) &R_H5Oincr_refcount, 1},
 {"R_H5Olink", (DL_FUNC) &R_H5Olink, 5},
 {"R_H5Oopen", (DL_FUNC) &R_H5Oopen, 3},
 {"R_H5Oopen_by_addr", (DL_FUNC) &R_H5Oopen_by_addr, 2},
 {"R_H5Oopen_by_idx", (DL_FUNC) &R_H5Oopen_by_idx, 6},
+{"R_H5Oopen_by_token", (DL_FUNC) &R_H5Oopen_by_token, 2},
 {"R_H5Orefresh", (DL_FUNC) &R_H5Orefresh, 1},
 {"R_H5Oset_comment", (DL_FUNC) &R_H5Oset_comment, 2},
 {"R_H5Oset_comment_by_name", (DL_FUNC) &R_H5Oset_comment_by_name, 4},
+{"R_H5Otoken_cmp", (DL_FUNC) &R_H5Otoken_cmp, 4},
+{"R_H5Otoken_from_str", (DL_FUNC) &R_H5Otoken_from_str, 3},
+{"R_H5Otoken_to_str", (DL_FUNC) &R_H5Otoken_to_str, 3},
 {NULL, NULL, 0}
 };
 
@@ -368,6 +383,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_create_intermediate_group", (DL_FUNC) &R_H5Pget_create_intermediate_group, 2},
 {"R_H5Pget_data_transform", (DL_FUNC) &R_H5Pget_data_transform, 3},
 {"R_H5Pget_driver", (DL_FUNC) &R_H5Pget_driver, 1},
+{"R_H5Pget_dset_no_attrs_hint", (DL_FUNC) &R_H5Pget_dset_no_attrs_hint, 2},
 {"R_H5Pget_edc_check", (DL_FUNC) &R_H5Pget_edc_check, 1},
 {"R_H5Pget_efile_prefix", (DL_FUNC) &R_H5Pget_efile_prefix, 3},
 {"R_H5Pget_elink_acc_flags", (DL_FUNC) &R_H5Pget_elink_acc_flags, 2},
@@ -425,6 +441,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_virtual_srcspace", (DL_FUNC) &R_H5Pget_virtual_srcspace, 2},
 {"R_H5Pget_virtual_view", (DL_FUNC) &R_H5Pget_virtual_view, 2},
 {"R_H5Pget_virtual_vspace", (DL_FUNC) &R_H5Pget_virtual_vspace, 2},
+{"R_H5Pget_vol_id", (DL_FUNC) &R_H5Pget_vol_id, 2},
 {"R_H5Pisa_class", (DL_FUNC) &R_H5Pisa_class, 2},
 {"R_H5Pmodify_filter", (DL_FUNC) &R_H5Pmodify_filter, 5},
 {"R_H5Premove", (DL_FUNC) &R_H5Premove, 2},
@@ -447,6 +464,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_data_transform", (DL_FUNC) &R_H5Pset_data_transform, 2},
 {"R_H5Pset_deflate", (DL_FUNC) &R_H5Pset_deflate, 2},
 {"R_H5Pset_driver", (DL_FUNC) &R_H5Pset_driver, 3},
+{"R_H5Pset_dset_no_attrs_hint", (DL_FUNC) &R_H5Pset_dset_no_attrs_hint, 2},
 {"R_H5Pset_edc_check", (DL_FUNC) &R_H5Pset_edc_check, 2},
 {"R_H5Pset_efile_prefix", (DL_FUNC) &R_H5Pset_efile_prefix, 2},
 {"R_H5Pset_elink_acc_flags", (DL_FUNC) &R_H5Pset_elink_acc_flags, 2},
@@ -500,17 +518,32 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_virtual_prefix", (DL_FUNC) &R_H5Pset_virtual_prefix, 2},
 {"R_H5Pset_virtual_printf_gap", (DL_FUNC) &R_H5Pset_virtual_printf_gap, 2},
 {"R_H5Pset_virtual_view", (DL_FUNC) &R_H5Pset_virtual_view, 2},
+{"R_H5Pset_vol", (DL_FUNC) &R_H5Pset_vol, 3},
 {"R_H5Punregister", (DL_FUNC) &R_H5Punregister, 2},
 {NULL, NULL, 0}
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5R[] = {
+{"R_H5Rcopy", (DL_FUNC) &R_H5Rcopy, 2},
 {"R_H5Rcreate", (DL_FUNC) &R_H5Rcreate, 6},
+{"R_H5Rcreate_attr", (DL_FUNC) &R_H5Rcreate_attr, 5},
+{"R_H5Rcreate_object", (DL_FUNC) &R_H5Rcreate_object, 4},
+{"R_H5Rcreate_region", (DL_FUNC) &R_H5Rcreate_region, 5},
 {"R_H5Rdereference1", (DL_FUNC) &R_H5Rdereference1, 3},
 {"R_H5Rdereference2", (DL_FUNC) &R_H5Rdereference2, 4},
+{"R_H5Rdestroy", (DL_FUNC) &R_H5Rdestroy, 1},
+{"R_H5Requal", (DL_FUNC) &R_H5Requal, 2},
+{"R_H5Rget_attr_name", (DL_FUNC) &R_H5Rget_attr_name, 3},
+{"R_H5Rget_file_name", (DL_FUNC) &R_H5Rget_file_name, 3},
 {"R_H5Rget_name", (DL_FUNC) &R_H5Rget_name, 5},
+{"R_H5Rget_obj_name", (DL_FUNC) &R_H5Rget_obj_name, 4},
 {"R_H5Rget_obj_type2", (DL_FUNC) &R_H5Rget_obj_type2, 4},
+{"R_H5Rget_obj_type3", (DL_FUNC) &R_H5Rget_obj_type3, 3},
 {"R_H5Rget_region", (DL_FUNC) &R_H5Rget_region, 3},
+{"R_H5Rget_type", (DL_FUNC) &R_H5Rget_type, 1},
+{"R_H5Ropen_attr", (DL_FUNC) &R_H5Ropen_attr, 3},
+{"R_H5Ropen_object", (DL_FUNC) &R_H5Ropen_object, 3},
+{"R_H5Ropen_region", (DL_FUNC) &R_H5Ropen_region, 3},
 {NULL, NULL, 0}
 };
 
@@ -537,11 +570,20 @@ R_CallMethodDef library_WRAPPER_AUTO_H5S[] = {
 {"R_H5Sget_simple_extent_type", (DL_FUNC) &R_H5Sget_simple_extent_type, 1},
 {"R_H5Sis_regular_hyperslab", (DL_FUNC) &R_H5Sis_regular_hyperslab, 1},
 {"R_H5Sis_simple", (DL_FUNC) &R_H5Sis_simple, 1},
+{"R_H5Smodify_select", (DL_FUNC) &R_H5Smodify_select, 3},
 {"R_H5Soffset_simple", (DL_FUNC) &R_H5Soffset_simple, 2},
+{"R_H5Ssel_iter_close", (DL_FUNC) &R_H5Ssel_iter_close, 1},
+{"R_H5Ssel_iter_create", (DL_FUNC) &R_H5Ssel_iter_create, 3},
+{"R_H5Ssel_iter_get_seq_list", (DL_FUNC) &R_H5Ssel_iter_get_seq_list, 7},
+{"R_H5Sselect_adjust", (DL_FUNC) &R_H5Sselect_adjust, 2},
 {"R_H5Sselect_all", (DL_FUNC) &R_H5Sselect_all, 1},
+{"R_H5Sselect_copy", (DL_FUNC) &R_H5Sselect_copy, 2},
 {"R_H5Sselect_elements", (DL_FUNC) &R_H5Sselect_elements, 4},
 {"R_H5Sselect_hyperslab", (DL_FUNC) &R_H5Sselect_hyperslab, 6},
+{"R_H5Sselect_intersect_block", (DL_FUNC) &R_H5Sselect_intersect_block, 3},
 {"R_H5Sselect_none", (DL_FUNC) &R_H5Sselect_none, 1},
+{"R_H5Sselect_project_intersection", (DL_FUNC) &R_H5Sselect_project_intersection, 3},
+{"R_H5Sselect_shape_same", (DL_FUNC) &R_H5Sselect_shape_same, 2},
 {"R_H5Sselect_valid", (DL_FUNC) &R_H5Sselect_valid, 1},
 {"R_H5Sset_extent_none", (DL_FUNC) &R_H5Sset_extent_none, 1},
 {"R_H5Sset_extent_simple", (DL_FUNC) &R_H5Sset_extent_simple, 4},
@@ -598,6 +640,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5T[] = {
 {"R_H5Tlock", (DL_FUNC) &R_H5Tlock, 1},
 {"R_H5Topen2", (DL_FUNC) &R_H5Topen2, 3},
 {"R_H5Tpack", (DL_FUNC) &R_H5Tpack, 1},
+{"R_H5Treclaim", (DL_FUNC) &R_H5Treclaim, 5},
 {"R_H5Trefresh", (DL_FUNC) &R_H5Trefresh, 1},
 {"R_H5Tset_cset", (DL_FUNC) &R_H5Tset_cset, 2},
 {"R_H5Tset_ebias", (DL_FUNC) &R_H5Tset_ebias, 2},
