@@ -17,7 +17,7 @@ SEXP R_H5Pcopy_prop(SEXP R_dst_id, SEXP R_src_id, SEXP R_name);
 SEXP R_H5Pcreate(SEXP R_cls_id);
 /* H5_DLL hid_t H5Pdecode(const void *buf); */
 SEXP R_H5Pdecode(SEXP R_buf);
-/* H5_DLL herr_t H5Pencode(hid_t plist_id, void *buf, size_t *nalloc); */
+/* H5_DLL herr_t H5Pencode1(hid_t plist_id, void *buf, size_t *nalloc); */
 SEXP R_H5Pencode(SEXP R_plist_id, SEXP R_buf, SEXP R_nalloc, SEXP _dupl_buf);
 /* H5_DLL htri_t H5Pequal(hid_t id1, hid_t id2); */
 SEXP R_H5Pequal(SEXP R_id1, SEXP R_id2);
@@ -65,6 +65,8 @@ SEXP R_H5Pget_create_intermediate_group(SEXP R_plist_id, SEXP R_crt_intmd);
 SEXP R_H5Pget_data_transform(SEXP R_plist_id, SEXP R_expression, SEXP R_size);
 /* H5_DLL hid_t H5Pget_driver(hid_t plist_id); */
 SEXP R_H5Pget_driver(SEXP R_plist_id);
+/* H5_DLL herr_t H5Pget_dset_no_attrs_hint(hid_t dcpl_id, hbool_t *minimize); */
+SEXP R_H5Pget_dset_no_attrs_hint(SEXP R_dcpl_id, SEXP R_minimize);
 /* H5_DLL H5Z_EDC_t H5Pget_edc_check(hid_t plist_id); */
 SEXP R_H5Pget_edc_check(SEXP R_plist_id);
 /* H5_DLL ssize_t H5Pget_efile_prefix(hid_t dapl_id, char* prefix , size_t size); */
@@ -79,6 +81,8 @@ SEXP R_H5Pget_elink_file_cache_size(SEXP R_plist_id, SEXP R_efc_size);
 SEXP R_H5Pget_elink_prefix(SEXP R_plist_id, SEXP R_prefix, SEXP R_size);
 /* H5_DLL herr_t H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries , unsigned *est_name_len ); */
 SEXP R_H5Pget_est_link_info(SEXP R_plist_id, SEXP R_est_num_entries, SEXP R_est_name_len);
+/* H5_DLL herr_t H5Pget_evict_on_close(hid_t fapl_id, hbool_t *evict_on_close); */
+SEXP R_H5Pget_evict_on_close(SEXP R_fapl_id, SEXP R_evict_on_close);
 /* H5_DLL herr_t H5Pget_external(hid_t plist_id, unsigned idx, size_t name_size, char *name, off_t *offset, hsize_t *size); */
 SEXP R_H5Pget_external(SEXP R_plist_id, SEXP R_idx, SEXP R_name_size, SEXP R_name, SEXP R_offset, SEXP R_size);
 /* H5_DLL int H5Pget_external_count(hid_t plist_id); */
@@ -89,14 +93,18 @@ SEXP R_H5Pget_family_offset(SEXP R_fapl_id, SEXP R_offset);
 SEXP R_H5Pget_fclose_degree(SEXP R_fapl_id, SEXP R_degree);
 /* H5_DLL herr_t H5Pget_file_space(hid_t plist_id, H5F_file_space_type_t *strategy, hsize_t *threshold); */
 SEXP R_H5Pget_file_space(SEXP R_plist_id, SEXP R_strategy, SEXP R_threshold);
+/* H5_DLL herr_t H5Pget_file_space_page_size(hid_t plist_id, hsize_t *fsp_size); */
+SEXP R_H5Pget_file_space_page_size(SEXP R_plist_id, SEXP R_fsp_size);
+/* H5_DLL herr_t H5Pget_file_space_strategy(hid_t plist_id, H5F_fspace_strategy_t *strategy, hbool_t *persist, hsize_t *threshold); */
+SEXP R_H5Pget_file_space_strategy(SEXP R_plist_id, SEXP R_strategy, SEXP R_persist, SEXP R_threshold);
 /* H5_DLL herr_t H5Pget_fill_time(hid_t plist_id, H5D_fill_time_t *fill_time); */
 SEXP R_H5Pget_fill_time(SEXP R_plist_id, SEXP R_fill_time);
 /* H5_DLL herr_t H5Pget_fill_value(hid_t plist_id, hid_t type_id, void *value); */
 SEXP R_H5Pget_fill_value(SEXP R_plist_id, SEXP R_type_id, SEXP R_value, SEXP _dupl_value);
-/* H5_DLL H5Z_filter_t H5Pget_filter2(hid_t plist_id, unsigned filter, unsigned int *flags, size_t *cd_nelmts, unsigned cd_values[], size_t namelen, char name[], unsigned *filter_config ); */
-SEXP R_H5Pget_filter2(SEXP R_plist_id, SEXP R_filter, SEXP R_flags, SEXP R_cd_nelmts, SEXP R_cd_values, SEXP R_namelen, SEXP R_name, SEXP R_filter_config);
 /* H5_DLL herr_t H5Pget_filter_by_id2(hid_t plist_id, H5Z_filter_t id, unsigned int *flags, size_t *cd_nelmts, unsigned cd_values[], size_t namelen, char name[], unsigned *filter_config); */
 SEXP R_H5Pget_filter_by_id2(SEXP R_plist_id, SEXP R_id, SEXP R_flags, SEXP R_cd_nelmts, SEXP R_cd_values, SEXP R_namelen, SEXP R_name, SEXP R_filter_config);
+/* H5_DLL H5Z_filter_t H5Pget_filter2(hid_t plist_id, unsigned filter, unsigned int *flags, size_t *cd_nelmts, unsigned cd_values[], size_t namelen, char name[], unsigned *filter_config ); */
+SEXP R_H5Pget_filter2(SEXP R_plist_id, SEXP R_filter, SEXP R_flags, SEXP R_cd_nelmts, SEXP R_cd_values, SEXP R_namelen, SEXP R_name, SEXP R_filter_config);
 /* H5_DLL herr_t H5Pget_gc_references(hid_t fapl_id, unsigned *gc_ref); */
 SEXP R_H5Pget_gc_references(SEXP R_fapl_id, SEXP R_gc_ref);
 /* H5_DLL herr_t H5Pget_hyper_vector_size(hid_t fapl_id, size_t *size); */
@@ -115,6 +123,8 @@ SEXP R_H5Pget_link_phase_change(SEXP R_plist_id, SEXP R_max_compact, SEXP R_min_
 SEXP R_H5Pget_local_heap_size_hint(SEXP R_plist_id, SEXP R_size_hint);
 /* H5_DLL herr_t H5Pget_mdc_config(hid_t plist_id, H5AC_cache_config_t * config_ptr);  */
 SEXP R_H5Pget_mdc_config (SEXP R_plist_id, SEXP R_config_ptr);
+/* H5_DLL herr_t H5Pget_mdc_image_config(hid_t plist_id, H5AC_cache_image_config_t *config_ptr ); */
+SEXP R_H5Pget_mdc_image_config(SEXP R_plist_id, SEXP R_config_ptr);
 /* H5_DLL herr_t H5Pget_mdc_log_options(hid_t plist_id, hbool_t *is_enabled, char *location, size_t *location_size, hbool_t *start_on_access); */
 SEXP R_H5Pget_mdc_log_options(SEXP R_plist_id, SEXP R_is_enabled, SEXP R_location, SEXP R_location_size, SEXP R_start_on_access);
 /* H5_DLL herr_t H5Pget_meta_block_size(hid_t fapl_id, hsize_t *size); */
@@ -131,6 +141,8 @@ SEXP R_H5Pget_nlinks(SEXP R_plist_id, SEXP R_nlinks);
 SEXP R_H5Pget_nprops(SEXP R_id, SEXP R_nprops);
 /* H5_DLL herr_t H5Pget_obj_track_times(hid_t plist_id, hbool_t *track_times); */
 SEXP R_H5Pget_obj_track_times(SEXP R_plist_id, SEXP R_track_times);
+/* H5_DLL herr_t H5Pget_page_buffer_size(hid_t plist_id, size_t *buf_size, unsigned *min_meta_per, unsigned *min_raw_per); */
+SEXP R_H5Pget_page_buffer_size(SEXP R_plist_id, SEXP R_buf_size, SEXP R_min_meta_per, SEXP R_min_raw_per);
 /* H5_DLL int H5Pget_preserve(hid_t plist_id); */
 SEXP R_H5Pget_preserve(SEXP R_plist_id);
 /* H5_DLL herr_t H5Pget_shared_mesg_index(hid_t plist_id, unsigned index_num, unsigned *mesg_type_flags, unsigned *min_mesg_size); */
@@ -159,6 +171,8 @@ SEXP R_H5Pget_virtual_count(SEXP R_dcpl_id, SEXP R_count);
 SEXP R_H5Pget_virtual_dsetname(SEXP R_dcpl_id, SEXP R_index, SEXP R_name, SEXP R_size);
 /* H5_DLL ssize_t H5Pget_virtual_filename(hid_t dcpl_id, size_t index, char *name, size_t size); */
 SEXP R_H5Pget_virtual_filename(SEXP R_dcpl_id, SEXP R_index, SEXP R_name, SEXP R_size);
+/* H5_DLL ssize_t H5Pget_virtual_prefix(hid_t dapl_id, char* prefix , size_t size); */
+SEXP R_H5Pget_virtual_prefix(SEXP R_dapl_id, SEXP R_prefix, SEXP R_size);
 /* H5_DLL herr_t H5Pget_virtual_printf_gap(hid_t plist_id, hsize_t *gap_size); */
 SEXP R_H5Pget_virtual_printf_gap(SEXP R_plist_id, SEXP R_gap_size);
 /* H5_DLL hid_t H5Pget_virtual_srcspace(hid_t dcpl_id, size_t index); */
@@ -167,6 +181,8 @@ SEXP R_H5Pget_virtual_srcspace(SEXP R_dcpl_id, SEXP R_index);
 SEXP R_H5Pget_virtual_view(SEXP R_plist_id, SEXP R_view);
 /* H5_DLL hid_t H5Pget_virtual_vspace(hid_t dcpl_id, size_t index); */
 SEXP R_H5Pget_virtual_vspace(SEXP R_dcpl_id, SEXP R_index);
+/* H5_DLL herr_t H5Pget_vol_id(hid_t plist_id, hid_t *vol_id); */
+SEXP R_H5Pget_vol_id(SEXP R_plist_id, SEXP R_vol_id);
 /* H5_DLL htri_t H5Pisa_class(hid_t plist_id, hid_t pclass_id); */
 SEXP R_H5Pisa_class(SEXP R_plist_id, SEXP R_pclass_id);
 /* H5_DLL herr_t H5Pmodify_filter(hid_t plist_id, H5Z_filter_t filter, unsigned int flags, size_t cd_nelmts, const unsigned int cd_values[]); */
@@ -175,8 +191,8 @@ SEXP R_H5Pmodify_filter(SEXP R_plist_id, SEXP R_filter, SEXP R_flags, SEXP R_cd_
 SEXP R_H5Premove(SEXP R_plist_id, SEXP R_name);
 /* H5_DLL herr_t H5Premove_filter(hid_t plist_id, H5Z_filter_t filter); */
 SEXP R_H5Premove_filter(SEXP R_plist_id, SEXP R_filter);
-/* H5_DLL herr_t H5Pset(hid_t plist_id, const char *name, void *value); */
-SEXP R_H5Pset(SEXP R_plist_id, SEXP R_name, SEXP R_value, SEXP _dupl_value);
+/* H5_DLL herr_t H5Pset(hid_t plist_id, const char *name, const void *value); */
+SEXP R_H5Pset(SEXP R_plist_id, SEXP R_name, SEXP R_value);
 /* H5_DLL herr_t H5Pset_alignment(hid_t fapl_id, hsize_t threshold, hsize_t alignment); */
 SEXP R_H5Pset_alignment(SEXP R_fapl_id, SEXP R_threshold, SEXP R_alignment);
 /* H5_DLL herr_t H5Pset_alloc_time(hid_t plist_id, H5D_alloc_time_t alloc_time); */
@@ -211,6 +227,8 @@ SEXP R_H5Pset_data_transform(SEXP R_plist_id, SEXP R_expression);
 SEXP R_H5Pset_deflate(SEXP R_plist_id, SEXP R_aggression);
 /* H5_DLL herr_t H5Pset_driver(hid_t plist_id, hid_t driver_id, const void *driver_info); */
 SEXP R_H5Pset_driver(SEXP R_plist_id, SEXP R_driver_id, SEXP R_driver_info);
+/* H5_DLL herr_t H5Pset_dset_no_attrs_hint(hid_t dcpl_id, hbool_t minimize); */
+SEXP R_H5Pset_dset_no_attrs_hint(SEXP R_dcpl_id, SEXP R_minimize);
 /* H5_DLL herr_t H5Pset_edc_check(hid_t plist_id, H5Z_EDC_t check); */
 SEXP R_H5Pset_edc_check(SEXP R_plist_id, SEXP R_check);
 /* H5_DLL herr_t H5Pset_efile_prefix(hid_t dapl_id, const char* prefix); */
@@ -225,6 +243,8 @@ SEXP R_H5Pset_elink_file_cache_size(SEXP R_plist_id, SEXP R_efc_size);
 SEXP R_H5Pset_elink_prefix(SEXP R_plist_id, SEXP R_prefix);
 /* H5_DLL herr_t H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len); */
 SEXP R_H5Pset_est_link_info(SEXP R_plist_id, SEXP R_est_num_entries, SEXP R_est_name_len);
+/* H5_DLL herr_t H5Pset_evict_on_close(hid_t fapl_id, hbool_t evict_on_close); */
+SEXP R_H5Pset_evict_on_close(SEXP R_fapl_id, SEXP R_evict_on_close);
 /* H5_DLL herr_t H5Pset_external(hid_t plist_id, const char *name, off_t offset, hsize_t size); */
 SEXP R_H5Pset_external(SEXP R_plist_id, SEXP R_name, SEXP R_offset, SEXP R_size);
 /* H5_DLL herr_t H5Pset_family_offset(hid_t fapl_id, hsize_t offset); */
@@ -235,6 +255,10 @@ SEXP R_H5Pset_fclose_degree(SEXP R_fapl_id, SEXP R_degree);
 SEXP R_H5Pset_file_image(SEXP R_fapl_id, SEXP R_buf_ptr, SEXP R_buf_len, SEXP _dupl_buf_ptr);
 /* H5_DLL herr_t H5Pset_file_space(hid_t plist_id, H5F_file_space_type_t strategy, hsize_t threshold); */
 SEXP R_H5Pset_file_space(SEXP R_plist_id, SEXP R_strategy, SEXP R_threshold);
+/* H5_DLL herr_t H5Pset_file_space_page_size(hid_t plist_id, hsize_t fsp_size); */
+SEXP R_H5Pset_file_space_page_size(SEXP R_plist_id, SEXP R_fsp_size);
+/* H5_DLL herr_t H5Pset_file_space_strategy(hid_t plist_id, H5F_fspace_strategy_t strategy, hbool_t persist, hsize_t threshold); */
+SEXP R_H5Pset_file_space_strategy(SEXP R_plist_id, SEXP R_strategy, SEXP R_persist, SEXP R_threshold);
 /* H5_DLL herr_t H5Pset_fill_time(hid_t plist_id, H5D_fill_time_t fill_time); */
 SEXP R_H5Pset_fill_time(SEXP R_plist_id, SEXP R_fill_time);
 /* H5_DLL herr_t H5Pset_fill_value(hid_t plist_id, hid_t type_id, const void *value); */
@@ -261,6 +285,8 @@ SEXP R_H5Pset_link_phase_change(SEXP R_plist_id, SEXP R_max_compact, SEXP R_min_
 SEXP R_H5Pset_local_heap_size_hint(SEXP R_plist_id, SEXP R_size_hint);
 /* H5_DLL herr_t H5Pset_mdc_config(hid_t plist_id, H5AC_cache_config_t * config_ptr); */
 SEXP R_H5Pset_mdc_config(SEXP R_plist_id, SEXP R_config_ptr);
+/* H5_DLL herr_t H5Pset_mdc_image_config(hid_t plist_id, H5AC_cache_image_config_t *config_ptr); */
+SEXP R_H5Pset_mdc_image_config(SEXP R_plist_id, SEXP R_config_ptr);
 /* H5_DLL herr_t H5Pset_mdc_log_options(hid_t plist_id, hbool_t is_enabled, const char *location, hbool_t start_on_access); */
 SEXP R_H5Pset_mdc_log_options(SEXP R_plist_id, SEXP R_is_enabled, SEXP R_location, SEXP R_start_on_access);
 /* H5_DLL herr_t H5Pset_meta_block_size(hid_t fapl_id, hsize_t size); */
@@ -275,6 +301,8 @@ SEXP R_H5Pset_nbit(SEXP R_plist_id);
 SEXP R_H5Pset_nlinks(SEXP R_plist_id, SEXP R_nlinks);
 /* H5_DLL herr_t H5Pset_obj_track_times(hid_t plist_id, hbool_t track_times); */
 SEXP R_H5Pset_obj_track_times(SEXP R_plist_id, SEXP R_track_times);
+/* H5_DLL herr_t H5Pset_page_buffer_size(hid_t plist_id, size_t buf_size, unsigned min_meta_per, unsigned min_raw_per); */
+SEXP R_H5Pset_page_buffer_size(SEXP R_plist_id, SEXP R_buf_size, SEXP R_min_meta_per, SEXP R_min_raw_per);
 /* H5_DLL herr_t H5Pset_preserve(hid_t plist_id, hbool_t status); */
 SEXP R_H5Pset_preserve(SEXP R_plist_id, SEXP R_status);
 /* H5_DLL herr_t H5Pset_scaleoffset(hid_t plist_id, H5Z_SO_scale_type_t scale_type, int scale_factor); */
@@ -301,10 +329,14 @@ SEXP R_H5Pset_szip(SEXP R_plist_id, SEXP R_options_mask, SEXP R_pixels_per_block
 SEXP R_H5Pset_userblock(SEXP R_plist_id, SEXP R_size);
 /* H5_DLL herr_t H5Pset_virtual(hid_t dcpl_id, hid_t vspace_id, const char *src_file_name, const char *src_dset_name, hid_t src_space_id); */
 SEXP R_H5Pset_virtual(SEXP R_dcpl_id, SEXP R_vspace_id, SEXP R_src_file_name, SEXP R_src_dset_name, SEXP R_src_space_id);
+/* H5_DLL herr_t H5Pset_virtual_prefix(hid_t dapl_id, const char* prefix); */
+SEXP R_H5Pset_virtual_prefix(SEXP R_dapl_id, SEXP R_prefix);
 /* H5_DLL herr_t H5Pset_virtual_printf_gap(hid_t plist_id, hsize_t gap_size); */
 SEXP R_H5Pset_virtual_printf_gap(SEXP R_plist_id, SEXP R_gap_size);
 /* H5_DLL herr_t H5Pset_virtual_view(hid_t plist_id, H5D_vds_view_t view); */
 SEXP R_H5Pset_virtual_view(SEXP R_plist_id, SEXP R_view);
+/* H5_DLL herr_t H5Pset_vol(hid_t plist_id, hid_t new_vol_id, const void *new_vol_info); */
+SEXP R_H5Pset_vol(SEXP R_plist_id, SEXP R_new_vol_id, SEXP R_new_vol_info);
 /* H5_DLL herr_t H5Punregister(hid_t pclass_id, const char *name); */
 SEXP R_H5Punregister(SEXP R_pclass_id, SEXP R_name);
 #endif
